@@ -1,7 +1,7 @@
 /*
  * Higher level bjnp IO communication implementation for
  * bjnp backend for the Common UNIX Printing System (CUPS).
- * Copyright 2008-2014 by Louis Lagendijk
+ * Copyright 2008-2020 by Louis Lagendijk
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -62,7 +62,7 @@ typedef enum bjnp_ink_level_t {
     LEVEL_UNKNOWN = 3
 } bjnp_ink_level_t;
 
-struct printer_s {
+typedef struct printer_s {
     int fd;                   /* tcp socket for the printer */
     http_addr_t printer_sa;   /* address struct for printer */
 
@@ -103,6 +103,6 @@ struct printer_s {
 
     int first_output;         /* at first output we report additional info */
     time_t last_level_report; /* last time we reported the levels */
-} printer_s;
+} printer_t;
 
 #endif
